/// <reference types="react" />
import { VDomModel, VDomRenderer } from '@jupyterlab/apputils';
import * as lsProtocol from 'vscode-languageserver-protocol';
import * as CodeMirror from 'codemirror';
import { IEditorPosition } from '../../../positioning';
import { VirtualEditor } from '../../../virtual/editor';
import { VirtualDocument } from '../../../virtual/document';
import '../../../../style/diagnostics_listing.css';
/**
 * Diagnostic which is localized at a specific editor (cell) within a notebook
 * (if used in the context of a FileEditor, then there is just a single editor)
 */
export interface IEditorDiagnostic {
    diagnostic: lsProtocol.Diagnostic;
    editor: CodeMirror.Editor;
    range: {
        start: IEditorPosition;
        end: IEditorPosition;
    };
}
export declare class DiagnosticsDatabase extends Map<VirtualDocument, IEditorDiagnostic[]> {
    get all(): Array<IEditorDiagnostic>;
}
export declare class DiagnosticsListing extends VDomRenderer<DiagnosticsListing.Model> {
    sort_key: string;
    sort_direction: number;
    constructor(model: DiagnosticsListing.Model);
    sort(key: string): void;
    render(): JSX.Element;
}
export declare namespace DiagnosticsListing {
    /**
     * A VDomModel for the LSP of current file editor/notebook.
     */
    class Model extends VDomModel {
        diagnostics: DiagnosticsDatabase;
        virtual_editor: VirtualEditor;
        constructor();
    }
}
